summaryrefslogtreecommitdiff
path: root/src/net/manaserv/protocol.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/net/manaserv/protocol.h')
-rw-r--r--src/net/manaserv/protocol.h7
1 files changed, 5 insertions, 2 deletions
diff --git a/src/net/manaserv/protocol.h b/src/net/manaserv/protocol.h
index d1ff3f73..fe38f35c 100644
--- a/src/net/manaserv/protocol.h
+++ b/src/net/manaserv/protocol.h
@@ -40,10 +40,12 @@
*/
enum {
// Login/Register
- PAMSG_REGISTER = 0x0000, // L version, S username, S password, S email
+ PAMSG_REGISTER = 0x0000, // L version, S username, S password, S email, S captcha response
APMSG_REGISTER_RESPONSE = 0x0002, // B error [, S updatehost]
PAMSG_UNREGISTER = 0x0003, // -
APMSG_UNREGISTER_RESPONSE = 0x0004, // B error
+ PAMSG_REQUEST_REGISTER_INFO = 0x0005, //
+ APMSG_REGISTER_INFO_RESPONSE = 0x0006, // B byte registrationAllowed, byte minEmailLength, byte maxEmailLength, byte minNameLength, byte maxNameLength, byte minPasswordLength, byte maxPasswordLength, string captchaURL, string captchaInstructions
PAMSG_LOGIN = 0x0010, // L version, S username, S password
APMSG_LOGIN_RESPONSE = 0x0012, // B error [, S updatehost]
PAMSG_LOGOUT = 0x0013, // -
@@ -238,7 +240,8 @@ enum {
enum {
REGISTER_INVALID_VERSION = 0x40, // the user is using an incompatible protocol
REGISTER_EXISTS_USERNAME, // there already is an account with this username
- REGISTER_EXISTS_EMAIL // there already is an account with this email address
+ REGISTER_EXISTS_EMAIL, // there already is an account with this email address
+ REGISTER_FAILED_CAPTCHA // captcha respose is bad
};
// Character creation specific return values